@@ -798,6 +798,9 @@ def cli(sys_argv):
     logging.getLogger('ludwig').setLevel(
         logging_level_registry[args.logging_level]
     )
+    global logger
+    logger = logging.getLogger('ludwig.train')
+
     set_on_master(args.use_horovod)
 
     if is_on_master():
